// Modules to control application life and create native browser window
const { app, BrowserWindow, Menu, ipcMain } = require("electron");
const path = require("path");
const ipc = require("./ipc/ipc").ipc;

global.windows = {};

function createWindow() {
  // Create the browser window.
  global.windows = new BrowserWindow({
    width: 1000,
    height: 650,
    minHeight: 600,
    minWidth: 800,
    webPreferences: {
      nodeIntegration: true,
      contextIsolation: true,
      preload: path.join(__dirname, "preload.js"),
    },
  });

  global.windows.loadURL("http://127.0.0.1:3000").then((r) => {
    console.log(r);
  });

  // mainWindow.loadFile('./build/index.html')

  // Open the DevTools.
  global.windows.webContents.openDevTools();

  global.windows.setTitle("Todo App");
}

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.whenReady().then(() => {
  createWindow();

  app.on("activate", function () {
    // On macOS it's common to re-create a window in the app when the
    // dock icon is clicked and there are no other windows open.
    if (BrowserWindow.getAllWindows().length === 0) createWindow();
  });
});

// Quit when all windows are closed, except on macOS. There, it's common
// for applications and their menu bar to stay active until the user quits
// explicitly with Cmd + Q.
app.on("window-all-closed", function () {
  // if (process.platform !== "darwin") app.quit();
  app.quit();
});

for (const key in ipc) {
  for (const event in ipc[key]) {
    console.log("registering ipc event", key, event);
    ipcMain.on(key + "-" + event, (e, ...args) => {
      console.log("ipc event", key, event, args);
      ipc[key][event](...args);
    });
  }
}

//设置菜单
// let dockMenu = Menu.buildFromTemplate([
//   {
//     label: "fileset",
//     submenu: [{ label: "文件" }],
//   },
//   {
//     label: "编辑",
//     submenu: [{ label: "保存" }, { label: "另存" }],
//   },
//   { label: "帮助", submenu: [{ label: "关于" }] },
// ]);
// Menu.setApplicationMenu(dockMenu);

// In this file you can include the rest of your app's specific main process
// code. You can also put them in separate files and require them here.
